﻿using System;
using C1.Win.TreeView;
using C1.Framework;

namespace CheckBox_TreeView
{
    class CustomPresenter : CustomContentPresenter
    {
        private CheckButtonElementEx _checkboxElement;
        private TextElement _textElement;
        private RowPanel _rowPanel;

        public CustomPresenter()
        {
            //init node elements
            _checkboxElement = new CheckButtonElementEx();
            _textElement = new TextElement();
            _rowPanel = new RowPanel();

            _checkboxElement.Size = new System.Drawing.Size(20, 20);

            //add elements in the RowPanel
            _rowPanel.Children.Add(_checkboxElement);
            _rowPanel.Children.Add(_textElement);

            Child = _rowPanel;
        }

        public override void SetStyle(TreeNodeCellStyles styles)
        {
            //setting the styles for node elements
            base.SetStyle(styles);
            _checkboxElement.Node = Node;
            _textElement.Style = new Style
            {
                Margins = new Thickness(2, 0, 0, 0),
                HorizontalAlignment = Alignment.Center,
                VerticalAlignment = Alignment.Center
            };

            _checkboxElement.Style = new Style
            {
                HorizontalAlignment = Alignment.Center,
                VerticalAlignment = Alignment.Center
            };
        }

        public override void SetValue(object value)
        {
            //if tag is false, remove the checkbox
            if (Node.Tag != null)
            {
                try
                {
                    if (!Convert.ToBoolean(Node.Tag))
                    {
                        _rowPanel.Children.Remove(_checkboxElement);
                    }
                }
                catch
                {
                    throw new NotSupportedException("Please set only boolean values in the Tag");
                }
            }

            //set the text and check state
            _textElement.Text = Node.GetValue().ToString();
            _checkboxElement.Checked = Node.CheckState == CheckState.Checked;
        }

        public override string ToolTipText { get { return _textElement.Text; } }

        public override void SetFormat(string format)
        {

        }
    }
}
